import { Module } from '@nestjs/common';
import { CqrsModule } from '@nestjs/cqrs';
import { DatabaseModule } from '../database/database.module';
import { ConfigurationController } from './adapters/primaries/configuration.controller';
import { ConfigurationRepository } from './adapters/secondaries/configuration.repository';
import { CreateConfigurationUseCase } from './domain/usecases/create-configuration.usecase';
import { DeleteConfigurationUseCase } from './domain/usecases/delete-configuration.usecase';
import { FindAllConfigurationsUseCase } from './domain/usecases/find-all-configurations.usecase';
import { FindConfigurationByUuidUseCase } from './domain/usecases/find-configuration-by-uuid.usecase';
import { UpdateConfigurationUseCase } from './domain/usecases/update-configuration.usecase';
import { ConfigurationProfile } from './mappers/configuration.profile';

@Module({
  imports: [DatabaseModule, CqrsModule],
  exports: [],
  controllers: [ConfigurationController],
  providers: [
    ConfigurationProfile,
    ConfigurationRepository,
    FindAllConfigurationsUseCase,
    FindConfigurationByUuidUseCase,
    CreateConfigurationUseCase,
    UpdateConfigurationUseCase,
    DeleteConfigurationUseCase,
  ],
})
export class ConfigurationModule {}
